@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2006  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2007  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -161,6 +161,10 @@ typedef struct {
 
 #define L2CAP_CONF_MAX_SIZE	22
 
+#define L2CAP_MODE_BASIC	0x00
+#define L2CAP_MODE_RETRANS	0x01
+#define L2CAP_MODE_FLOWCTL	0x02
+
 typedef struct {
 	uint16_t	dcid;
 	uint16_t	scid;
@@ -175,7 +179,6 @@ typedef struct {
 
 typedef struct {
 	uint16_t	type;
-	uint8_t		data[0];
 } __attribute__ ((packed)) l2cap_info_req;
 #define L2CAP_INFO_REQ_SIZE 2
 
