@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2006  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2007  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 
 #include <stdio.h>
 #include <errno.h>
+#include <ctype.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <malloc.h>
@@ -110,6 +111,40 @@ int ba2oui(const bdaddr_t *ba, char *str)
 	return sprintf(str, "%2.2X-%2.2X-%2.2X", b[0], b[1], b[2]);
 }
 
+int bachk(const char *str)
+{
+	char tmp[18], *ptr = tmp;
+
+	if (!str)
+		return -1;
+
+	if (strlen(str) != 17)
+		return -1;
+
+	memcpy(tmp, str, 18);
+
+	while (*ptr) {
+		*ptr = toupper(*ptr);
+		if (*ptr < '0'|| (*ptr > '9' && *ptr < 'A') || *ptr > 'F')
+			return -1;
+		ptr++;
+
+		*ptr = toupper(*ptr);
+		if (*ptr < '0'|| (*ptr > '9' && *ptr < 'A') || *ptr > 'F')
+			return -1;
+		ptr++;
+
+		*ptr = toupper(*ptr);
+		if (*ptr == 0)
+			break;
+		if (*ptr != ':')
+			return -1;
+		ptr++;
+	}
+
+	return 0;
+}
+
 int baprintf(const char *format, ...)
 {
 	va_list ap;
@@ -384,6 +419,20 @@ char *bt_compidtostr(int compid)
 		return "PARROT SA";
 	case 68:
 		return "Socket Communications";
+	case 69:
+		return "Atheros Communications, Inc.";
+	case 70:
+		return "MediaTek, Inc.";
+	case 71:
+		return "Bluegiga";	/* (tentative) */
+	case 72:
+		return "Marvell Technology Group Ltd.";
+	case 73:
+		return "3DSP Corporation";
+	case 74:
+		return "Accel Semiconductor Ltd.";
+	case 75:
+		return "Continental Automotive Systems";
 	case 65535:
 		return "internal use";
 	default:
